﻿using System.Linq;
using System.Threading.Tasks;
using Microsoft.Azure.Documents;
using Microsoft.Azure.Documents.Client;
using Microsoft.Azure.Documents.Linq;

namespace SqlXmlVsDocumentDb
{
    public class DocDbHelper
    {
        private readonly DocumentClient _client;

        public DocDbHelper(DocumentClient client)
        {
            _client = client;
        }

        public async Task<Database> GetOrCreateDatabaseAsync(string id)
        {
            var database = _client.CreateDatabaseQuery()
                .Where(db => db.Id == id)
                .AsEnumerable()
                .FirstOrDefault();

            if (database == null)
            {
                return await _client.CreateDatabaseAsync(new Database {Id = id});
            }

            return database;
        }

        public async Task<DocumentCollection> GetOrCreateDocumentCollectionAsync(Database database, string id)
        {
            var collection = _client.CreateDocumentCollectionQuery(database.CollectionsLink)
                .Where(c => c.Id == id)
                .AsEnumerable()
                .FirstOrDefault();

            if (collection == null)
            {
                return await _client.CreateDocumentCollectionAsync(
                    database.CollectionsLink,
                    new DocumentCollection { Id = id });
            }

            return collection;
        }

        public async Task CreateDocumentAsync<T>(DocumentCollection collection, T document)
        {
            await _client.CreateDocumentAsync(collection.DocumentsLink, document);
        }
    }
}
